@@ -22,6 +22,9 @@
 /* we include the references also */
 #include "references.h"
 
+/* need config to figure out what needs to be defined or not */
+#include "config.h"
+
 #ifndef M_E
 # define M_E            2.7182818284590452354   /* e */
 #endif
@@ -55,17 +58,6 @@
 #define POW_7_3(x) pow((x), 7.0/3.0)
 #endif
 
-#ifdef _MSC_VER
-#define strcasecmp  _stricmp
-#define strncasecmp _strnicmp
-
-double asinh (double x);
-float  asinhf(float  x);
-double erf(double);
-double erfc(double);
-#endif
-
-
 #define M_SQRTPI        1.772453850905516027298167483341145182798L
 #define M_SQRT3         1.732050807568877293527446341505872366943L
 #define M_CBRT2         1.259921049894873164767210607278228350570L
@@ -120,7 +112,7 @@ double xc_bessel_K0(const double x);
 double xc_bessel_K1_scaled(const double x);
 double xc_bessel_K1(const double x);
 
-double xc_expint_e1_impl(const double x, const int scale);
+double xc_expint_e1_impl(double x, const int scale);
 static inline double expint_e1(const double x)         { return  xc_expint_e1_impl( x, 0); }
 static inline double expint_e1_scaled(const double x)  { return  xc_expint_e1_impl( x, 1); }
 static inline double expint_Ei(const double x)         { return -xc_expint_e1_impl(-x, 0); }
@@ -320,29 +312,7 @@ typedef struct xc_mgga_work_c_t {
 } xc_mgga_work_c_t;
 
 
-/* now the routines to set the _internal_ parameters of several functionals */
-void xc_gga_x_pw91_set_params(xc_func_type *p, double a, double b, double c, double d, double f, double alpha, double expo);
-void xc_gga_x_pw91_set_params2(xc_func_type *p, double bt, double alpha, double expo);
-void xc_gga_x_ssb_sw_set_params(xc_func_type *p, double A, double B, double C, double D, double E);
-void xc_gga_x_hjs_set_params(xc_func_type *p, double omega);
-void xc_gga_x_hjs_b88_v2_set_params(xc_func_type *p, double omega);
-void xc_gga_x_b88_set_params(xc_func_type *p, double beta, double gamma);
-void xc_gga_x_optx_set_params(xc_func_type *p, double a, double b, double gamma);
-void xc_gga_x_wpbeh_set_params(xc_func_type *p, double omega);
-void xc_gga_x_pbe_set_params(xc_func_type *p, double kappa, double mu);
-void xc_gga_x_pbeint_set_params(xc_func_type *p, double kappa, double alpha, double muPBE, double muGE);
-void xc_gga_x_ityh_set_params(xc_func_type *p, int func_id, double omega);
-void xc_gga_x_b86_set_params(xc_func_type *p, double beta, double gamma, double omega);
-void xc_gga_x_rpbe_set_params(xc_func_type *p, double kappa, double mu);
-void xc_gga_x_sfat_set_params(xc_func_type *p, int func_id, double omega);
-void xc_gga_x_kt_set_params(xc_func_type *p, double gamma, double delta);
-void xc_gga_c_lyp_set_params(xc_func_type *p, double A, double B, double c, double d);
-void xc_gga_c_pbe_set_params(xc_func_type *p, double beta);
-
-void xc_mgga_x_tpss_set_params(xc_func_type *p, double b, double c, double e, double kappa, double mu, double BLOC_a, double BLOC_b);
-void xc_mgga_c_tpss_set_params(xc_func_type *p, double beta, double d, double C0_0, double C0_1, double C0_2, double C0_3);
-void xc_mgga_c_pkzb_set_params(xc_func_type *p, double beta, double d, double C0_0, double C0_1, double C0_2, double C0_3);
-void xc_mgga_c_bc95_set_params(xc_func_type *p, double css, double copp);
+void xc_mgga_x_scan_falpha(int order, double a, double c1, double c2, double dd, double *f, double *dfda);
 
 /* useful MACROS */
 #define DFRACTION(num, dnum, den, dden) \
